Index: channels/chan_zap.c
===================================================================
--- channels/chan_zap.c	(revision 16867)
+++ channels/chan_zap.c	(working copy)
@@ -7938,7 +7938,7 @@
 			break;
 		}
 	}
-	
+
 	return principle;
 }
 
@@ -8424,8 +8424,8 @@
 					/* Check for an event */
 					x = 0;
 					res = ioctl(pri->fds[which], ZT_GETEVENT, &x);
-					if (x) 
-						ast_log(LOG_NOTICE, "PRI got event: %s (%d) on %s D-channel of span %d\n", event2str(x), x, pri_order(which), pri->span);
+					if (x)
+						ast_log(LOG_NOTICE, "PRI got event: %s (%d) on %s D-channel of span %d\n", event2str(x), x, pri_order(which), pri->span);	
 					/* Keep track of alarm state */	
 					if (x == ZT_EVENT_ALARM) {
 						pri->dchanavail[which] &= ~(DCHAN_NOTINALARM | DCHAN_UP);
@@ -9793,6 +9793,7 @@
 	char tmps[20] = "";
 	ast_mutex_t *lock;
 	struct zt_pvt *start;
+	char *requestedcontext = NULL;
 #ifdef ZAPATA_PRI
 	int trunkgroup;
 	struct zt_pri *pri=NULL;
@@ -9804,25 +9805,36 @@
 
 #ifdef ZAPATA_PRI
 	if (argc == 4) {
-		if ((trunkgroup = atoi(argv[3])) < 1)
-			return RESULT_SHOWUSAGE;
-		for (x=0;x<NUM_SPANS;x++) {
-			if (pris[x].trunkgroup == trunkgroup) {
-				pri = pris + x;
-				break;
+		if ((trunkgroup = atoi(argv[3])) < 1) {
+			/* If argv[3] is a number, assume it's a trunkgroup,
+			 * otherwise assume it's the requested context
+			 */
+			requestedcontext = argv[3];
+		} else {
+			for (x=0;x<NUM_SPANS;x++) {
+				if (pris[x].trunkgroup == trunkgroup) {
+					pri = pris + x;
+					break;
+				}
 			}
+			if (pri) {
+				start = pri->crvs;
+				lock = &pri->lock;
+			} else {
+				ast_cli(fd, "No such trunk group %d\n", trunkgroup);
+				return RESULT_FAILURE;
+			}
 		}
-		if (pri) {
-			start = pri->crvs;
-			lock = &pri->lock;
-		} else {
-			ast_cli(fd, "No such trunk group %d\n", trunkgroup);
-			return RESULT_FAILURE;
-		}
-	} else
-#endif
-	if (argc != 3)
+	} else {
+		if (argc !=3)
+			return RESULT_SHOWUSAGE;
+	}
+#else
+	if (argc < 3 || argc > 4)
 		return RESULT_SHOWUSAGE;
+	if (argc == 4)
+		requestedcontext = argv[4];
+#endif	
 
 	ast_mutex_lock(lock);
 #ifdef ZAPATA_PRI
@@ -9833,11 +9845,14 @@
 	
 	tmp = start;
 	while (tmp) {
-		if (tmp->channel > 0) {
-			snprintf(tmps, sizeof(tmps), "%d", tmp->channel);
-		} else
-			ast_copy_string(tmps, "pseudo", sizeof(tmps));
-		ast_cli(fd, FORMAT, tmps, tmp->exten, tmp->context, tmp->language, tmp->musicclass);
+		if (requestedcontext == NULL
+		 || !strcasecmp(requestedcontext, tmp->context)) {
+			if (tmp->channel > 0)
+				snprintf(tmps, sizeof(tmps), "%d", tmp->channel);
+			else
+				ast_copy_string(tmps, "pseudo", sizeof(tmps));
+			ast_cli(fd, FORMAT, tmps, tmp->exten, tmp->context, tmp->language, tmp->musicclass);
+		}
 		tmp = tmp->next;
 	}
 	ast_mutex_unlock(lock);
@@ -10079,7 +10094,11 @@
 }
 
 static char show_channels_usage[] =
-	"Usage: zap show channels\n"
+#ifdef ZAPATA_PRI
+	"Usage: zap show channels [context | trunkgroup]\n"
+#else
+	"Usage: zap show channels [context]\n"
+#endif
 	"	Shows a list of available channels\n";
 
 static char show_channel_usage[] =
